from typing import Optional
from pydantic import BaseModel
from datetime import datetime


# Shared properties
class JobTitleBase(BaseModel):
    title: Optional[str] = None
    description: Optional[str] = None


# Properties to receive via API on creation
class JobTitleCreate(JobTitleBase):
    title: str


# Properties to receive via API on update
class JobTitleUpdate(JobTitleBase):
    pass


class JobTitleInDBBase(JobTitleBase):
    id: Optional[str] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True


# Additional properties to return via API
class JobTitle(JobTitleInDBBase):
    pass


# Additional properties stored in DB
class JobTitleInDB(JobTitleInDBBase):
    pass